@@ -7,7 +7,9 @@ import os.path
 import site
 import subprocess
 import sys
-from typing import Any, Sequence
+from typing import Any
+
+from packaging.version import Version
 
 
 def as_list(content: Any | list[Any] | tuple[Any, ...]) -> list[Any]:
@@ -57,37 +59,16 @@ def scripts(interpreter: str) -> str:
     )
 
 
+def version(executable: str) -> Version:
+    """Returns the version of the executable at the given path."""
+    output = subprocess.check_output([executable, "--version"]).decode().strip()
+    version = output.replace("ruff ", "")  # no removeprefix in 3.7 :/
+    return Version(version)
+
+
 class RunResult:
     """Object to hold result from running tool."""
 
-    def __init__(self, stdout: str, stderr: str):
-        self.stdout: str = stdout
-        self.stderr: str = stderr
-
-
-def run_path(
-    argv: Sequence[str],
-    use_stdin: bool,
-    cwd: str,
-    source: str | None = None,
-) -> RunResult:
-    """Runs as an executable."""
-    if use_stdin:
-        with subprocess.Popen(
-            argv,
-            encoding="utf-8",
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            stdin=subprocess.PIPE,
-            cwd=cwd,
-        ) as process:
-            return RunResult(*process.communicate(input=source))
-    else:
-        result = subprocess.run(
-            argv,
-            encoding="utf-8",
-            capture_output=True,
-            check=False,
-            cwd=cwd,
-        )
-        return RunResult(result.stdout, result.stderr)
+    def __init__(self, stdout: bytes, stderr: bytes):
+        self.stdout: bytes = stdout
+        self.stderr: bytes = stderr
