@@ -3,11 +3,13 @@ from __future__ import annotations
 
 import os
 import tempfile
-import unittest
 from threading import Event
 
+from packaging.version import Version
+
 from tests.client import defaults, session, utils
 
+# Increase this if you want to attach a debugger
 TIMEOUT_SECONDS = 10
 
 CONTENTS = """import sys
@@ -15,11 +17,19 @@ CONTENTS = """import sys
 print(x)
 """
 
+VERSION_REQUIREMENT_ASTRAL_DOCS = Version("0.0.291")
 
-class TestServer(unittest.TestCase):
+
+class TestServer:
     maxDiff = None
 
-    def test_linting_example(self):
+    def test_linting_example(self, ruff_version: Version) -> None:
+        expected_docs_url = (
+            "https://docs.astral.sh/ruff/"
+            if ruff_version >= VERSION_REQUIREMENT_ASTRAL_DOCS
+            else "https://beta.ruff.rs/docs/"
+        )
+
         with tempfile.NamedTemporaryFile(suffix=".py") as fp:
             fp.write(CONTENTS.encode())
             fp.flush()
@@ -55,49 +65,61 @@ class TestServer(unittest.TestCase):
                 done.wait(TIMEOUT_SECONDS)
 
                 expected = {
-                    "uri": uri,
                     "diagnostics": [
                         {
-                            "range": {
-                                "start": {"line": 0, "character": 7},
-                                "end": {"line": 0, "character": 10},
+                            "code": "F401",
+                            "codeDescription": {
+                                "href": expected_docs_url + "rules/unused-import"
                             },
                             "data": {
                                 "fix": {
-                                    "message": "Remove unused import: `sys`",
+                                    "applicability": "Automatic",
                                     "edits": [
                                         {
                                             "content": "",
-                                            "location": {"row": 1, "column": 0},
-                                            "end_location": {"row": 2, "column": 0},
+                                            "end_location": {"column": 0, "row": 2},
+                                            "location": {"column": 0, "row": 1},
                                         }
                                     ],
+                                    "message": "Remove unused import: `sys`",
                                 },
                                 "noqa_row": 1,
                             },
                             "message": "`sys` imported but unused",
+                            "range": {
+                                "end": {"character": 10, "line": 0},
+                                "start": {"character": 7, "line": 0},
+                            },
                             "severity": 2,
-                            "code": "F401",
                             "source": "Ruff",
                             "tags": [1],
                         },
                         {
-                            "range": {
-                                "start": {"line": 2, "character": 6},
-                                "end": {"line": 2, "character": 7},
+                            "code": "F821",
+                            "codeDescription": {
+                                "href": expected_docs_url + "rules/undefined-name"
                             },
                             "data": {"fix": None, "noqa_row": 3},
                             "message": "Undefined name `x`",
+                            "range": {
+                                "end": {"character": 7, "line": 2},
+                                "start": {"character": 6, "line": 2},
+                            },
                             "severity": 1,
-                            "code": "F821",
                             "source": "Ruff",
                         },
                     ],
+                    "uri": uri,
                 }
+            assert expected == actual
 
-            self.assertEqual(actual, expected)
+    def test_no_initialization_options(self, ruff_version: Version) -> None:
+        expected_docs_url = (
+            "https://docs.astral.sh/ruff/"
+            if ruff_version >= VERSION_REQUIREMENT_ASTRAL_DOCS
+            else "https://beta.ruff.rs/docs/"
+        )
 
-    def test_no_initialization_options(self):
         with tempfile.NamedTemporaryFile(suffix=".py") as fp:
             fp.write(CONTENTS.encode())
             fp.flush()
@@ -138,44 +160,50 @@ class TestServer(unittest.TestCase):
                 done.wait(TIMEOUT_SECONDS)
 
                 expected = {
-                    "uri": uri,
                     "diagnostics": [
                         {
-                            "range": {
-                                "start": {"line": 0, "character": 7},
-                                "end": {"line": 0, "character": 10},
+                            "code": "F401",
+                            "codeDescription": {
+                                "href": expected_docs_url + "rules/unused-import"
                             },
                             "data": {
                                 "fix": {
-                                    "message": "Remove unused import: `sys`",
+                                    "applicability": "Automatic",
                                     "edits": [
                                         {
                                             "content": "",
-                                            "location": {"row": 1, "column": 0},
-                                            "end_location": {"row": 2, "column": 0},
+                                            "end_location": {"column": 0, "row": 2},
+                                            "location": {"column": 0, "row": 1},
                                         }
                                     ],
+                                    "message": "Remove unused import: `sys`",
                                 },
                                 "noqa_row": 1,
                             },
                             "message": "`sys` imported but unused",
+                            "range": {
+                                "end": {"character": 10, "line": 0},
+                                "start": {"character": 7, "line": 0},
+                            },
                             "severity": 2,
-                            "code": "F401",
                             "source": "Ruff",
                             "tags": [1],
                         },
                         {
-                            "range": {
-                                "start": {"line": 2, "character": 6},
-                                "end": {"line": 2, "character": 7},
+                            "code": "F821",
+                            "codeDescription": {
+                                "href": expected_docs_url + "rules/undefined-name"
                             },
                             "data": {"fix": None, "noqa_row": 3},
                             "message": "Undefined name `x`",
+                            "range": {
+                                "end": {"character": 7, "line": 2},
+                                "start": {"character": 6, "line": 2},
+                            },
                             "severity": 1,
-                            "code": "F821",
                             "source": "Ruff",
                         },
                     ],
+                    "uri": uri,
                 }
-
-            self.assertEqual(actual, expected)
+            assert expected == actual
